import smtplib
from email.mime.multipart import MIMEMultipart

from flaschengeist.system.models.user import User
from flaschengeist.system.controller import userController
from flaschengeist.system.controller.messageController import Message

from . import Plugin, send_message_hook


class MailMessagePlugin(Plugin):
    def __init__(self, config):
        super().__init__()
        self.server = config['SERVER']
        self.port = config['PORT']
        self.user = config['USER']
        self.password = config['PASSWORD']
        self.crypt = config['CRYPT']
        self.mail = config['MAIL']

    @send_message_hook
    def send_mail(self, msg: Message):
        if isinstance(msg.receiver, User):
            recipients = [msg.receiver.mail]
        else:
            recipients = userController.get_user_by_role(msg.receiver)

        mail = MIMEMultipart()
        mail['From'] = self.mail
        mail['To'] = ", ".join(recipients)
        mail['Subject'] = msg.subject
        msg.attach(msg.message)
        if not self.smtp:
            self.__connect()
        self.smtp.sendmail(self.mail, recipients, msg.as_string())

    def __connect(self):
        if self.crypt == 'SSL':
            self.smtp = smtplib.SMTP_SSL(self.server, self.port)
        if self.crypt == 'STARTTLS':
            self.smtp = smtplib.SMTP(self.smtpServer, self.port)
            self.smtp.starttls()
        self.smtp.login(self.user, self.password)
